package com.landray.kmss.sys.attachment.restservice.dianju.controller;

import java.io.File;
import java.io.FileNotFoundException;
import org.apache.commons.io.FileUtils;
import java.nio.charset.StandardCharsets;
import org.springframework.util.ResourceUtils;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RequestMethod;
import java.io.InputStream;
import com.landray.kmss.sys.filestore.scheduler.third.dianju.dto.ConvertObserverParameter;
import com.alibaba.fastjson.JSONObject;
import java.io.IOException;
import org.springframework.web.bind.annotation.GetMapping;
import com.landray.kmss.web.action.ActionForm;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpServletRequest;
import com.landray.kmss.util.SpringBeanUtil;
import java.util.Observer;
import org.slf4j.LoggerFactory;
import com.landray.kmss.sys.attachment.integrate.dianju.interfaces.ISysAttachmentDianJuProvider;
import com.landray.kmss.sys.attachment.actions.SysAttMainAction;
import com.landray.kmss.sys.filestore.convert.service.CallbackHandle;
import com.landray.kmss.sys.filestore.convert.observer.ConvertObserver;
import com.landray.kmss.sys.filestore.convert.observer.ConvertObservable;
import org.slf4j.Logger;
import com.landray.kmss.web.annotation.RestApi;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.landray.kmss.common.rest.controller.BaseController;

@RestController
@RequestMapping({ "/api/sys-attachment/dianjuCallback" })
@RestApi(docUrl = "/sys/attachment/restservice/sysAttDianJuRestServiceHelp.jsp", name = "SysAttDianJuCallbackController", resourceKey = "sys-attachment:SysAttDianJuCallback.title")
public class SysAttDianJuCallbackController extends BaseController
{
    private static final Logger logger;
    private static ConvertObservable convertObservable;
    private static ConvertObserver convertObserver;
    private static CallbackHandle callbackHandle;
    private SysAttMainAction sysAttMainAction;
    private ISysAttachmentDianJuProvider sysAttachmentDianJuProvider;
    
    static {
        logger = LoggerFactory.getLogger(SysAttDianJuCallbackController.class);
        SysAttDianJuCallbackController.convertObservable = new ConvertObservable();
        SysAttDianJuCallbackController.convertObserver = new ConvertObserver(getCallbackHandle());
        SysAttDianJuCallbackController.convertObservable.addObserver((Observer)SysAttDianJuCallbackController.convertObserver);
        SysAttDianJuCallbackController.callbackHandle = null;
    }
    
    public SysAttDianJuCallbackController() {
        this.sysAttMainAction = new SysAttMainAction();
    }
    
    private static CallbackHandle getCallbackHandle() {
        if (SysAttDianJuCallbackController.callbackHandle == null) {
            SysAttDianJuCallbackController.callbackHandle = (CallbackHandle)SpringBeanUtil.getBean("dianjuCallbackHandleImpl");
        }
        return SysAttDianJuCallbackController.callbackHandle;
    }
    
    public ISysAttachmentDianJuProvider getSysAttachmentDianJuProvider() {
        if (this.sysAttachmentDianJuProvider == null) {
            this.sysAttachmentDianJuProvider = (ISysAttachmentDianJuProvider)SpringBeanUtil.getBean("sysAttachmentDianJuProvider");
        }
        return this.sysAttachmentDianJuProvider;
    }
    
    @GetMapping({ "/download" })
    public void download(final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        if (this.getSysAttachmentDianJuProvider().checkDownloadToken(request.getParameter("si"))) {
            this.sysAttMainAction.download(this.emptyMapping, (ActionForm)null, request, response);
        }
        else {
            SysAttDianJuCallbackController.logger.warn("点聚下载EKP文件，无效的下载请求" + request.getRequestURL().toString());
        }
    }
    
    @RequestMapping(value = { "/convert" }, method = { RequestMethod.POST })
    @ResponseBody
    public Object convert(final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        if (SysAttDianJuCallbackController.logger.isDebugEnabled()) {
            SysAttDianJuCallbackController.logger.debug("点聚转换已经回调接口convert......");
        }
        InputStream is = null;
        final StringBuilder callbackInfo = new StringBuilder();
        Label_0232: {
            try {
                is = (InputStream)request.getInputStream();
                final byte[] b = new byte[1024];
                int n;
                while ((n = is.read(b)) != -1) {
                    callbackInfo.append(new String(b, 0, n));
                }
            }
            catch (final IOException e) {
                SysAttDianJuCallbackController.logger.error("点聚转换回调问题：" + e);
                if (is != null) {
                    try {
                        is.close();
                    }
                    catch (final IOException e2) {
                        SysAttDianJuCallbackController.logger.error("点聚转换回调关闭流出现问题：" + e2);
                    }
                }
                break Label_0232;
            }
            finally {
                if (is != null) {
                    try {
                        is.close();
                    }
                    catch (final IOException e2) {
                        SysAttDianJuCallbackController.logger.error("点聚转换回调关闭流出现问题：" + e2);
                    }
                }
            }
            if (is != null) {
                try {
                    is.close();
                }
                catch (final IOException e2) {
                    SysAttDianJuCallbackController.logger.error("点聚转换回调关闭流出现问题：" + e2);
                }
            }
        }
        if (SysAttDianJuCallbackController.logger.isDebugEnabled()) {
            SysAttDianJuCallbackController.logger.debug("点聚转换回调的信息是：{}", callbackInfo.toString());
        }
        final JSONObject jsonObject = JSONObject.parseObject(callbackInfo.toString());
        final String taskId = jsonObject.getString("SERIAL_NUMBER");
        final String message = jsonObject.getString("RET_MSG");
        final String retCode = jsonObject.getString("retCode");
        if (!"1".equals(retCode)) {
            SysAttDianJuCallbackController.logger.error("点聚转换失败，回调信息为:SERIAL_NUMBER={},RET_MSG={},retCode={}", taskId, message, retCode);
        }
        if (SysAttDianJuCallbackController.logger.isDebugEnabled()) {
            SysAttDianJuCallbackController.logger.debug("点聚转换回调的信息进行解析得到SERIAL_NUMBER={},RET_MSG={}", taskId, message);
        }
        final ConvertObserverParameter convertObserverParameter = new ConvertObserverParameter().setTaskId(taskId).setMessage(message).setRetCode(retCode).setProductName("Dianju");
        SysAttDianJuCallbackController.convertObservable.handleConvertCallback((Object)convertObserverParameter);
        final JSONObject result = new JSONObject();
        result.put("RET_CODE", (Object)1);
        return result.toString();
    }
    
    public static void main(final String[] args) {
        final String cfgPath = "com/landray/kmss/sys/attachment/restservice/dianju/util/dianju_lightRead.json";
        try {
            final File file = ResourceUtils.getFile("classpath:" + cfgPath);
            final JSONObject props = JSONObject.parseObject(FileUtils.readFileToString(file, StandardCharsets.UTF_8));
            System.out.println(props.getString("dianju.lightRead.appUrl"));
        }
        catch (final FileNotFoundException e) {
            e.printStackTrace();
        }
        catch (final IOException e2) {
            e2.printStackTrace();
        }
    }
}
